@@ -357,147 +357,6 @@ if (!defined('vlibTemplateClassLoaded')) {
 			return true;
 		}
 
-		/**
-		 * [** EXPERIMENTAL **]
-		 * Function to create a loop from a Db result resource link.
-		 * @param string $loopname to commit loop. If not set, will use last loopname set using newLoop()
-		 * @param string $result link to a Db result resource
-		 * @param string $db_type, type of db that the result resource belongs to.
-		 * @return boolean true/false
-		 * @access public
-		 */
-		public function setDbLoop($loopname, $result, $db_type = 'MYSQL')
-		{
-			/*
-			$db_type = strtoupper($db_type);
-            if (!in_array($db_type, $this->allowed_loop_dbs)) {
-                vlibTemplateError::raiseError('VT_WARNING_INVALID_LOOP_DB', WARNING, $db_type);
-                return false;
-            }
-
-            $loop_arr = array();
-            // TODO: Are all these necessary as were onyl using mysql and possible postgres ? - pedro
-            switch ($db_type) {
-
-                case 'MYSQL':
-                    if (get_resource_type($result) != 'mysql result') {
-                        vlibTemplateError::raiseError('VT_WARNING_INVALID_RESOURCE', WARNING, $db_type);
-                        return false;
-                    }
-                    while($r = mysql_fetch_assoc($result)) {
-                        $loop_arr[] = $r;
-                    }
-                    break;
-
-                case 'POSTGRESQL':
-                    if (get_resource_type($result) != 'pgsql result') {
-                        vlibTemplateError::raiseError('VT_WARNING_INVALID_RESOURCE', WARNING, $db_type);
-                        return false;
-                    }
-
-                    $nr = (function_exists('pg_num_rows')) ? pg_num_rows($result) : pg_numrows($result);
-
-                    for ($i=0; $i < $nr; $i++) {
-                        $loop_arr[] = pg_fetch_array($result, $i, PGSQL_ASSOC);
-                    }
-                    break;
-
-                case 'INFORMIX':
-                    if (!$result) {
-                        vlibTemplateError::raiseError('VT_WARNING_INVALID_RESOURCE', WARNING, $db_type);
-                        return false;
-                    }
-                    while($r = ifx_fetch_row($result, 'NEXT')) {
-                        $loop_arr[] = $r;
-                    }
-                    break;
-
-                case 'INTERBASE':
-                    if (get_resource_type($result) != 'interbase result') {
-                        vlibTemplateError::raiseError('VT_WARNING_INVALID_RESOURCE', WARNING, $db_type);
-                        return false;
-                    }
-                    while($r = ibase_fetch_row($result)) {
-                        $loop_arr[] = $r;
-                    }
-                    break;
-
-                case 'INGRES':
-                    if (!$result) {
-                        vlibTemplateError::raiseError('VT_WARNING_INVALID_RESOURCE', WARNING, $db_type);
-                        return false;
-                    }
-                    while($r = ingres_fetch_array(INGRES_ASSOC, $result)) {
-                        $loop_arr[] = $r;
-                    }
-                    break;
-
-                case 'MSSQL':
-                    if (get_resource_type($result) != 'mssql result') {
-                        vlibTemplateError::raiseError('VT_WARNING_INVALID_RESOURCE', WARNING, $db_type);
-                        return false;
-                    }
-                    while($r = mssql_fetch_array($result)) {
-                        $loop_arr[] = $r;
-                    }
-                    break;
-
-                case 'MSQL':
-                    if (get_resource_type($result) != 'msql result') {
-                        vlibTemplateError::raiseError('VT_WARNING_INVALID_RESOURCE', WARNING, $db_type);
-                        return false;
-                    }
-                    while($r = msql_fetch_array($result, MSQL_ASSOC)) {
-                        $loop_arr[] = $r;
-                    }
-                    break;
-
-                case 'OCI8':
-                    if (get_resource_type($result) != 'oci8 statement') {
-                        vlibTemplateError::raiseError('VT_WARNING_INVALID_RESOURCE', WARNING, $db_type);
-                        return false;
-                    }
-                    while(OCIFetchInto($result, &$r, OCI_ASSOC+OCI_RETURN_LOBS)) {
-                        $loop_arr[] = $r;
-                    }
-                    break;
-
-                case 'ORACLE':
-                    if (get_resource_type($result) != 'oracle Cursor') {
-                        vlibTemplateError::raiseError('VT_WARNING_INVALID_RESOURCE', WARNING, $db_type);
-                        return false;
-                    }
-                    while(ora_fetch_into($result, &$r, ORA_FETCHINTO_ASSOC)) {
-                        $loop_arr[] = $r;
-                    }
-                    break;
-
-                case 'OVRIMOS':
-                    if (!$result) {
-                        vlibTemplateError::raiseError('VT_WARNING_INVALID_RESOURCE', WARNING, $db_type);
-                        return false;
-                    }
-                    while(ovrimos_fetch_into($result, &$r, 'NEXT')) {
-                        $loop_arr[] = $r;
-                    }
-                    break;
-
-                case 'SYBASE':
-                    if (get_resource_type($result) != 'sybase-db result') {
-                        vlibTemplateError::raiseError('VT_WARNING_INVALID_RESOURCE', WARNING, $db_type);
-                        return false;
-                    }
-
-                    while($r = sybase_fetch_array($result)) {
-                        $loop_arr[] = $r;
-                    }
-                    break;
-            }
-            $this->setLoop($loopname, $loop_arr);
-            return true;
-			*/
-		}
-
 		/**
 		 * Sets the name for the curent loop in the 3 step loop process.
 		 * @param string $name string to define loop name
