@@ -166,7 +166,7 @@ class ApsGUIController extends ApsBase
             FROM aps_packages
             WHERE name = (SELECT name FROM aps_packages WHERE id = ?)
             AND package_status = 2
-            ORDER BY REPLACE(version, '.', '')+0 DESC, `release` DESC", $id);
+            ORDER BY INET_ATON(SUBSTRING_INDEX(CONCAT(version,'.0.0.0'),'.',4)) DESC, `release` DESC", $id);
 
 		if(!empty($result) && ($id != $result['id'])) return $result['id'];
 
@@ -249,6 +249,15 @@ class ApsGUIController extends ApsBase
 			$settings['main_database_host'] = 'localhost';
 			$mysql_db_remote_access = 'n';
 			$mysql_db_remote_ips = '';
+
+			// If we are dealing with chrooted PHP-FPM, use a network connection instead because the MySQL socket file
+			// does not exist within the chroot.
+			$php_fpm_chroot = $app->db->queryOneRecord("SELECT php_fpm_chroot FROM web_domain WHERE domain_id = ?", $websrv['domain_id']);
+			if ($php_fpm_chroot['php_fpm_chroot'] === 'y') {
+				$settings['main_database_host'] = '127.0.0.1';
+				$mysql_db_remote_access = 'y';
+				$mysql_db_remote_ips = '127.0.0.1';
+			}
 		} else {
 			//* get the default database server of the client
 			$client = $app->db->queryOneRecord("SELECT default_dbserver FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = ?", $websrv['sys_groupid']);
@@ -417,6 +426,8 @@ class ApsGUIController extends ApsBase
 
 		//* Set package status to install afetr we inserted the settings
 		$app->db->datalogUpdate('aps_instances', array("instance_status" => INSTANCE_INSTALL), 'id', $InstanceID);
+		
+		return $InstanceID;
 	}
 
 	/**
@@ -556,6 +567,16 @@ class ApsGUIController extends ApsBase
 		}
 		else $error[] = $app->lng('error_main_domain');
 
+		if(isset($postinput['admin_password']))
+		{
+			$app->uses('validate_password');
+
+			$passwordError = $app->validate_password->password_check('', $postinput['admin_password'], '');
+			if ($passwordError) {
+				$error[] = $passwordError;
+			}
+		}
+
 		// Main location (not obligatory but must be supplied)
 		if(isset($postinput['main_location']))
 		{
@@ -846,7 +867,7 @@ class ApsGUIController extends ApsBase
 		$pkg['Requirements PHP extensions'] = trim($php_ext);
 
 		// PHP bool options
-		$pkg['Requirements PHP settings'] = '';
+		$pkg['Requirements PHP settings'] = array();
 		$php_bool_options = array('allow-url-fopen', 'file-uploads', 'magic-quotes-gpc',
 			'register-globals', 'safe-mode', 'short-open-tag');
 		foreach($php_bool_options as $option)
