@@ -58,6 +58,10 @@ class functions {
 		if($cc != '') $app->ispcmail->setHeader('Cc', $cc);
 		if($bcc != '') $app->ispcmail->setHeader('Bcc', $bcc);
 
+		if(is_string($to) && strpos($to, ',') !== false) {
+				$to = preg_split('/\s*,\s*/', $to);
+		}
+		
 		$app->ispcmail->send($to);
 		$app->ispcmail->finish();
 
@@ -447,13 +451,55 @@ class functions {
 		if(file_exists($id_rsa_file)) unset($id_rsa_file);
 		if(file_exists($id_rsa_pub_file)) unset($id_rsa_pub_file);
 		if(!file_exists($id_rsa_file) && !file_exists($id_rsa_pub_file)) {
-			exec('ssh-keygen -t rsa -C '.$username.'-rsa-key-'.time().' -f '.$id_rsa_file.' -N ""');
+			$app->system->exec_safe('ssh-keygen -t rsa -C ? -f ? -N ""', $username.'-rsa-key-'.time(), $id_rsa_file);
 			$app->db->query("UPDATE client SET created_at = UNIX_TIMESTAMP(), id_rsa = ?, ssh_rsa = ? WHERE client_id = ?", @file_get_contents($id_rsa_file), @file_get_contents($id_rsa_pub_file), $client_id);
-			exec('rm -f '.$id_rsa_file.' '.$id_rsa_pub_file);
+			$app->system->exec_safe('rm -f ? ?', $id_rsa_file, $id_rsa_pub_file);
 		} else {
 			$app->log("Failed to create SSH keypair for ".$username, LOGLEVEL_WARN);
 		}
 	}
+	
+	public function htmlentities($value) {
+		global $conf;
+
+		if(is_array($value)) {
+			$out = array();
+			foreach($value as $key => $val) {
+				if(is_array($val)) {
+					$out[$key] = $this->htmlentities($val);
+				} else {
+					$out[$key] = htmlentities($val, ENT_QUOTES, $conf["html_content_encoding"]);
+				}
+			}
+		} else {
+			$out = htmlentities($value, ENT_QUOTES, $conf["html_content_encoding"]);
+		}
+		
+		return $out;
+	}
+	
+	// Function to check paths before we use it as include. Use with absolute paths only.
+	public function check_include_path($path) {
+		if(strpos($path,'//') !== false) die('Include path seems to be an URL: '.$this->htmlentities($path));
+		if(strpos($path,'..') !== false) die('Two dots are not allowed in include path: '.$this->htmlentities($path));
+		if(!preg_match("/^[a-zA-Z0-9_\/\.\-]+$/", $path)) die('Wrong chars in include path: '.$this->htmlentities($path));
+		$path = realpath($path);
+		if($path == '') die('Include path does not exist.');
+		if(substr($path,0,strlen(ISPC_ROOT_PATH)) != ISPC_ROOT_PATH) die('Path '.$this->htmlentities($path).' is outside of ISPConfig installation directory.');
+		return $path;
+	}
+	
+	// Function to check language strings
+	public function check_language($language) {
+		global $app;
+		if(preg_match('/^[a-z]{2}$/',$language)) {
+			 return $language;
+		} else {
+			$app->log('Wrong language string: '.$this->htmlentities($language),1);
+			return 'en';	
+		}
+	}
+	
 }
 
 ?>
