@@ -331,7 +331,7 @@ class remoting_client extends remoting {
 			return false;
 		}
 
-		if(@is_numeric($client_id) && @is_numeric($template_id)) {
+		if(@is_numeric($client_id) && @is_numeric($assigned_template_id)) {
 			// check if client exists
 			$check = $app->db->queryOneRecord('SELECT `client_id` FROM `client` WHERE `client_id` = ?', $client_id);
 			if(!$check) {
@@ -339,7 +339,7 @@ class remoting_client extends remoting {
 				return false;
 			}
 			// check if template exists
-			$check = $app->db->queryOneRecord('SELECT `assigned_template_id` FROM `client_template_assigned` WHERE `assigned_template_id` = ?', $assigned_template_id);
+			$check = $app->db->queryOneRecord('SELECT `assigned_template_id` FROM `client_template_assigned` WHERE `client_id` = ? AND `client_template_id` = ?', $client_id, $assigned_template_id);
 			if(!$check) {
 				throw new SoapFault('Invalid template');
 				return false;
@@ -349,7 +349,7 @@ class remoting_client extends remoting {
 			$this->_set_client_formdata($client_id);
 
 			$sql = "DELETE FROM `client_template_assigned` WHERE `assigned_template_id` = ? AND `client_id` = ?";
-			$app->db->query($sql, $template_id, $client_id);
+			$app->db->query($sql, $check['assigned_template_id'], $client_id);
 			$affected_rows = $app->db->affectedRows();
 
 			$app->plugin->raiseEvent('client:client:on_after_update', $this);
@@ -604,11 +604,9 @@ class remoting_client extends remoting {
 			if($user) {
 				$saved_password = stripslashes($user['password']);
 
-				if(substr($saved_password, 0, 3) == '$1$') {
-					//* The password is crypt-md5 encrypted
-					$salt = '$1$'.substr($saved_password, 3, 8).'$';
-
-					if(crypt(stripslashes($password), $salt) != $saved_password) {
+				if(preg_match('/^\$[156]\$/', $saved_password)) {
+					//* The password is crypt encrypted
+					if(crypt(stripslashes($password), $saved_password) !== $saved_password) {
 						$user = false;
 					}
 				} else {
@@ -636,11 +634,9 @@ class remoting_client extends remoting {
 			if($user) {
 				$saved_password = stripslashes($user['passwort']);
 
-				if(substr($saved_password, 0, 3) == '$1$') {
+				if(preg_match('/^\$[156]\$/', $saved_password)) {
 					//* The password is crypt-md5 encrypted
-					$salt = '$1$'.substr($saved_password, 3, 8).'$';
-
-					if(crypt(stripslashes($password), $salt) != $saved_password) {
+					if(crypt(stripslashes($password), $saved_password) != $saved_password) {
 						$user = false;
 					}
 				} else {
@@ -678,6 +674,27 @@ class remoting_client extends remoting {
 		
 		return $returnval;
 	}
+	
+	public function client_get_by_groupid($session_id, $group_id)
+	{
+		global $app;
+		if(!$this->checkPerm($session_id, 'client_get_id')) {
+			throw new SoapFault('permission_denied', 'You do not have the permissions to access this function.');
+			return false;
+		}
+
+		$group_id = $app->functions->intval($group_id);
+
+		$rec = $app->db->queryOneRecord("SELECT client_id FROM sys_group WHERE groupid = ?", $group_id);
+		if(isset($rec['client_id'])) {
+			$client_id = $app->functions->intval($rec['client_id']);
+			return $this->client_get($session_id, $client_id);
+		} else {
+			throw new SoapFault('no_group_found', 'There is no client for this group ID.');
+			return false;
+		}
+	}
+
 }
 
 ?>
