@@ -99,28 +99,22 @@ class remoting {
 			if($user) {
 				$saved_password = stripslashes($user['passwort']);
 
-				if(substr($saved_password, 0, 3) == '$1$') {
+				if(preg_match('/^\$[156]\$/', $saved_password)) {
 					//* The password is crypt-md5 encrypted
-					$salt = '$1$'.substr($saved_password, 3, 8).'$';
-
-					if(crypt(stripslashes($password), $salt) != $saved_password) {
+					if(crypt(stripslashes($password), $saved_password) != $saved_password) {
 						throw new SoapFault('client_login_failed', 'The login failed. Username or password wrong.');
-						return false;
 					}
 				} else {
 					//* The password is md5 encrypted
 					if(md5($password) != $saved_password) {
 						throw new SoapFault('client_login_failed', 'The login failed. Username or password wrong.');
-						return false;
 					}
 				}
 			} else {
 				throw new SoapFault('client_login_failed', 'The login failed. Username or password wrong.');
-				return false;
 			}
 			if($user['active'] != 1) {
 				throw new SoapFault('client_login_failed', 'The login failed. User is blocked.');
-				return false;
 			}
 
 			// now we need the client data
@@ -144,6 +138,45 @@ class remoting {
 			$sql = "SELECT * FROM remote_user WHERE remote_username = ? and remote_password = md5(?)";
 			$remote_user = $app->db->queryOneRecord($sql, $username, $password);
 			if($remote_user['remote_userid'] > 0) {
+				if (trim($remote_user['remote_ips']) != '') {
+					$allowed_ips = explode(',',$remote_user['remote_ips']);
+					foreach($allowed_ips as $i => $allowed) { 
+						if(!filter_var($allowed, FILTER_VALIDATE_IP)) { 
+							// get the ip for a hostname
+							unset($allowed_ips[$i]);
+							$temp=dns_get_record($allowed, DNS_A+DNS_AAAA);
+							if(is_array($temp) && !empty($temp)) {
+								foreach($temp as $t) {
+									if(isset($t['ip'])) $allowed_ips[] = $t['ip'];
+									if(isset($t['ipv6'])) $allowed_ips[] = $t['ipv6'];
+								}
+								unset($temp);
+							}
+						}
+					}
+				}
+				$allowed_ips[] = '127.0.0.1';
+				$allowed_ips[] = '::1';
+				$allowed_ips=array_unique($allowed_ips);
+				$ip = $_SERVER['REMOTE_ADDR'];
+				$remote_allowed = @($ip == '::1' || $ip == '127.0.0.1')?true:false;
+				if(!$remote_allowed && $remote_user['remote_access'] == 'y') {
+					if(trim($remote_user['remote_ips']) == '') {
+						$remote_allowed=true;
+					} else {
+						$ip = inet_pton($_SERVER['REMOTE_ADDR']);
+						foreach($allowed_ips as $allowed) {
+							if($ip == inet_pton(trim($allowed))) {
+								$remote_allowed=true;
+								break;
+							}
+						}
+					}
+				}
+				if(!$remote_allowed) {
+					throw new SoapFault('login_failed', 'The login is not allowed from '.$_SERVER['REMOTE_ADDR']);
+					return false;
+				}	
 				//* Create a remote user session
 				//srand ((double)microtime()*1000000);
 				$remote_session = md5(mt_rand().uniqid('ispco'));
@@ -208,7 +241,14 @@ class remoting {
 
 		//* Execute the SQL query
 		$app->db->query($sql);
-		$insert_id = $app->db->insertID();
+		if($app->db->errorMessage != '') {
+			throw new SoapFault('database_error', $app->db->errorMessage . ' '.$sql);
+			return false;
+		}
+		if ( isset($params['_primary_id'] ))
+			$insert_id = $params['_primary_id'];
+		else
+			$insert_id = $app->db->insertID();
 
 
 		//* Stop on error while executing the sql query
@@ -295,7 +335,10 @@ class remoting {
 			return false;
 		}
 
-		$insert_id = $app->db->insertID();
+		if ( isset($params['_primary_id'] ))
+			$insert_id = $params['_primary_id'];
+		else
+			$insert_id = $app->db->insertID();
 
 		// set a few values for compatibility with tform actions, mostly used by plugins
 		$this->id = $insert_id;
@@ -334,7 +377,7 @@ class remoting {
 		$app->remoting_lib->loadFormDef($formdef_file);
 		
 		//* get old record and merge with params, so only new values have to be set in $params
-		$old_rec = $app->remoting_lib->getDataRecord($primary_id);
+               $old_rec = $app->remoting_lib->getDataRecord($primary_id, $client_id);
 		
 		foreach ($app->remoting_lib->formDef['fields'] as $fieldName => $fieldConf)
         {
