@@ -110,6 +110,10 @@ class tform_actions {
 		$app->plugin->raiseEvent($_SESSION['s']['module']['name'].':'.$app->tform->formDef['name'].':'.'on_before_update', $this);
 
 		$ext_where = '';
+		// pre-fill dataRecord array with elements from database to avoid overwriting fields set by admin but hidden for client
+		//$tmp_old_record = $app->tform->getDataRecord($this->id);
+		//if($tmp_old_record && is_array($tmp_old_record)) $this->dataRecord = array_merge($tmp_old_record, $this->dataRecord);
+		// disabled due to problems with mail users, see https://git.ispconfig.org/ispconfig/ispconfig3/issues/4513
 		$sql = $app->tform->getSQL($this->dataRecord, $app->tform->getCurrentTab(), 'UPDATE', $this->id, $ext_where);
 		if($app->tform->errorMessage == '') {
 
@@ -283,7 +287,7 @@ class tform_actions {
 		global $app, $conf;
 
 		$app->tpl->setVar("error", "<li>".$app->tform->errorMessage."</li>");
-		$app->tpl->setVar($this->dataRecord);
+		$app->tpl->setVar($this->dataRecord, null, true);
 		$this->onShow();
 	}
 
@@ -293,6 +297,9 @@ class tform_actions {
 	 */
 	function onDelete() {
 		global $app, $conf, $list_def_file, $tform_def_file;
+		
+		// Check CSRF Token
+		$app->auth->csrf_token_check('GET');
 
 		include_once $list_def_file;
 
