@@ -104,6 +104,7 @@ class tform_base {
 	var $module;
 	var $primary_id;
 	var $diffrec = array();
+	var $primary_id_override = 0;
 
 	/**
 	 * Loading of the table definition
@@ -133,7 +134,7 @@ class tform_base {
 		$this->module = $module;
 		$wb = array();
 
-		include_once ISPC_ROOT_PATH.'/lib/lang/'.$_SESSION['s']['language'].'.lng';
+		include_once ISPC_ROOT_PATH.'/lib/lang/'.$app->functions->check_language($_SESSION['s']['language']).'.lng';
 
 		if(is_array($wb)) $wb_global = $wb;
 
@@ -142,7 +143,7 @@ class tform_base {
 			if(!file_exists($lng_file)) $lng_file = "lib/lang/en_".$this->formDef["name"].".lng";
 			include $lng_file;
 		} else {
-			$lng_file = "../$module/lib/lang/".$_SESSION["s"]["language"]."_".$this->formDef["name"].".lng";
+			$lng_file = "../$module/lib/lang/".$app->functions->check_language($_SESSION["s"]["language"])."_".$this->formDef["name"].".lng";
 			if(!file_exists($lng_file)) $lng_file = "../$module/lib/lang/en_".$this->formDef["name"].".lng";
 			include $lng_file;
 		}
@@ -244,7 +245,7 @@ class tform_base {
 	 */
 	function decode($record, $tab) {
 		global $conf, $app;
-		if(!is_array($this->formDef['tabs'][$tab])) $app->error("Tab does not exist or the tab is empty (TAB: $tab).");
+		if(!is_array($this->formDef['tabs'][$tab])) $app->error("Tab does not exist or the tab is empty (TAB: ".$app->functions->htmlentities($tab).").");
 		return $this->_decode($record, $tab, false);
 	}
 
@@ -335,69 +336,84 @@ class tform_base {
 	}
 
 	//* If the parameter 'valuelimit' is set
-	function applyValueLimit($limit, $values) {
+	function applyValueLimit($limit, $values, $current_value = '') {
 
 		global $app;
+		
+		// we mas have multiple limits, therefore we explode by ; first
+		// Example: "system:sites:web_php_options;client:web_php_options"
+		$limits = explode(';',$limit);
+		
+		
+		foreach($limits as $limit) {
 
-		$limit_parts = explode(':', $limit);
+			$limit_parts = explode(':', $limit);
 
-		//* values are limited to a comma separated list
-		if($limit_parts[0] == 'list') {
-			$allowed = explode(',', $limit_parts[1]);
-		}
-
-		//* values are limited to a field in the client settings
-		if($limit_parts[0] == 'client') {
-			if($_SESSION["s"]["user"]["typ"] == 'admin') {
-				return $values;
-			} else {
-				$client_group_id = $_SESSION["s"]["user"]["default_group"];
-				$client = $app->db->queryOneRecord("SELECT ".$limit_parts[1]." as lm FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = ?", $client_group_id);
-				$allowed = explode(',', $client['lm']);
+			//* values are limited to a comma separated list
+			if($limit_parts[0] == 'list') {
+				$allowed = explode(',', $limit_parts[1]);
 			}
-		}
 
-		//* values are limited to a field in the reseller settings
-		if($limit_parts[0] == 'reseller') {
-			if($_SESSION["s"]["user"]["typ"] == 'admin') {
-				return $values;
-			} else {
-				//* Get the limits of the client that is currently logged in
-				$client_group_id = $_SESSION["s"]["user"]["default_group"];
-				$client = $app->db->queryOneRecord("SELECT parent_client_id FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = ?", $client_group_id);
-				//echo "SELECT parent_client_id FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = $client_group_id";
-				//* If the client belongs to a reseller, we will check against the reseller Limit too
-				if($client['parent_client_id'] != 0) {
-
-					//* first we need to know the groups of this reseller
-					$tmp = $app->db->queryOneRecord("SELECT userid, groups FROM sys_user WHERE client_id = ?", $client['parent_client_id']);
-					$reseller_groups = $tmp["groups"];
-					$reseller_userid = $tmp["userid"];
-
-					// Get the limits of the reseller of the logged in client
-					$client_group_id = $_SESSION["s"]["user"]["default_group"];
-					$reseller = $app->db->queryOneRecord("SELECT ".$limit_parts[1]." as lm FROM client WHERE client_id = ?", $client['parent_client_id']);
-					$allowed = explode(',', $reseller['lm']);
-				} else {
+			//* values are limited to a field in the client settings
+			if($limit_parts[0] == 'client') {
+				if($_SESSION["s"]["user"]["typ"] == 'admin') {
 					return $values;
+				} else {
+					$client_group_id = $_SESSION["s"]["user"]["default_group"];
+					$client = $app->db->queryOneRecord("SELECT ".$limit_parts[1]." as lm FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = ?", $client_group_id);
+					$allowed = explode(',', $client['lm']);
 				}
-			} // end if admin
-		} // end if reseller
+			}
+
+			//* values are limited to a field in the reseller settings
+			if($limit_parts[0] == 'reseller') {
+				if($_SESSION["s"]["user"]["typ"] == 'admin') {
+					return $values;
+				} else {
+					//* Get the limits of the client that is currently logged in
+					$client_group_id = $_SESSION["s"]["user"]["default_group"];
+					$client = $app->db->queryOneRecord("SELECT parent_client_id FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = ?", $client_group_id);
+					//echo "SELECT parent_client_id FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = $client_group_id";
+					//* If the client belongs to a reseller, we will check against the reseller Limit too
+					if($client['parent_client_id'] != 0) {
+
+						//* first we need to know the groups of this reseller
+						$tmp = $app->db->queryOneRecord("SELECT userid, groups FROM sys_user WHERE client_id = ?", $client['parent_client_id']);
+						$reseller_groups = $tmp["groups"];
+						$reseller_userid = $tmp["userid"];
+
+						// Get the limits of the reseller of the logged in client
+						$client_group_id = $_SESSION["s"]["user"]["default_group"];
+						$reseller = $app->db->queryOneRecord("SELECT ".$limit_parts[1]." as lm FROM client WHERE client_id = ?", $client['parent_client_id']);
+						$allowed = explode(',', $reseller['lm']);
+					} else {
+						return $values;
+					}
+				} // end if admin
+			} // end if reseller
+
+			//* values are limited to a field in the system settings
+			if($limit_parts[0] == 'system') {
+				$app->uses('getconf');
+				$tmp_conf = $app->getconf->get_global_config($limit_parts[1]);
+				$tmp_key = $limit_parts[2];
+				$allowed = $allowed = explode(',',$tmp_conf[$tmp_key]);
+			}
+			
+			// add the current value to the allowed array
+			$allowed[] = $current_value;
+
+			// remove all values that are not allowed
+			$values_new = array();
+			foreach($values as $key => $val) {
+				if(in_array($key, $allowed)) $values_new[$key] = $val;
+			}
+
+			$values = $values_new;
 
-		//* values are limited to a field in the system settings
-		if($limit_parts[0] == 'system') {
-			$app->uses('getconf');
-			$tmp_conf = $app->getconf->get_global_config($limit_parts[1]);
-			$tmp_key = $limit_parts[2];
-			$allowed = $tmp_conf[$tmp_key];
 		}
 
-		$values_new = array();
-		foreach($values as $key => $val) {
-			if(in_array($key, $allowed)) $values_new[$key] = $val;
-		}
-
-		return $values_new;
+		return $values;
 	}
 
 
@@ -415,7 +431,7 @@ class tform_base {
 		$this->action = $action;
 
 		if(!is_array($this->formDef)) $app->error("No form definition found.");
-		if(!is_array($this->formDef['tabs'][$tab])) $app->error("The tab is empty or does not exist (TAB: $tab).");
+		if(!is_array($this->formDef['tabs'][$tab])) $app->error("The tab is empty or does not exist (TAB: ".$app->functions->htmlentities($tab).").");
 
 		/* CSRF PROTECTION */
 		// generate csrf protection id and key
@@ -463,7 +479,7 @@ class tform_base {
 
 					// If a limitation for the values is set
 					if(isset($field['valuelimit']) && is_array($field["value"])) {
-						$field["value"] = $this->applyValueLimit($field['valuelimit'], $field["value"]);
+						$field["value"] = $this->applyValueLimit($field['valuelimit'], $field["value"], $val);
 					}
 
 					switch ($field['formtype']) {
@@ -472,8 +488,8 @@ class tform_base {
 						if(is_array($field['value'])) {
 							foreach($field['value'] as $k => $v) {
 								$selected = ($k == $val)?' SELECTED':'';
-								if(isset($this->wordbook[$v]))
-									$v = $this->wordbook[$v];
+								if(isset($this->wordbook[$v])) $v = $this->wordbook[$v];
+								else $v = $app->functions->htmlentities($v);
 								$out .= "<option value='$k'$selected>".$this->lng($v)."</option>\r\n";
 							}
 						}
@@ -493,7 +509,7 @@ class tform_base {
 								foreach($vals as $tvl) {
 									if(trim($tvl) == trim($k)) $selected = ' SELECTED';
 								}
-
+								$v = $app->functions->htmlentities($v);
 								$out .= "<option value='$k'$selected>$v</option>\r\n";
 							}
 						}
@@ -576,7 +592,7 @@ class tform_base {
 					
 					default:
 						if(isset($record[$key])) {
-							$new_record[$key] = htmlspecialchars($record[$key]);
+							$new_record[$key] = $app->functions->htmlentities($record[$key]);
 						} else {
 							$new_record[$key] = '';
 						}
@@ -598,7 +614,7 @@ class tform_base {
 
 				// If a limitation for the values is set
 				if(isset($field['valuelimit']) && is_array($field["value"])) {
-					$field["value"] = $this->applyValueLimit($field['valuelimit'], $field["value"]);
+					$field["value"] = $this->applyValueLimit($field['valuelimit'], $field["value"], $field['default']);
 				}
 
 				switch ($field['formtype']) {
@@ -607,7 +623,8 @@ class tform_base {
 						$out = '';
 						foreach($field['value'] as $k => $v) {
 							$selected = ($k == $field["default"])?' SELECTED':'';
-							$out .= "<option value='$k'$selected>".$this->lng($v)."</option>\r\n";
+							$v = $app->functions->htmlentities($this->lng($v));
+							$out .= "<option value='$k'$selected>".$v."</option>\r\n";
 						}
 					}
 					if(isset($out)) $new_record[$key] = $out;
@@ -621,7 +638,7 @@ class tform_base {
 						// HTML schreiben
 						$out = '';
 						foreach($field['value'] as $k => $v) {
-
+							$v = $app->functions->htmlentities($v);
 							$out .= "<option value='$k'>$v</option>\r\n";
 						}
 					}
@@ -692,7 +709,7 @@ class tform_base {
 					break;
 
 				default:
-					$new_record[$key] = htmlspecialchars($field['default']);
+					$new_record[$key] = $app->functions->htmlentities($field['default']);
 				}
 			}
 
@@ -807,7 +824,7 @@ class tform_base {
 					$new_record[$key] = $record[$key];
 					break;
 				case 'CURRENCY':
-					$new_record[$key] = str_replace(",", ".", $record[$key]);
+					$new_record[$key] = $app->functions->currency_unformat($record[$key]);
 					break;
 
 				case 'DATETIME':
@@ -866,7 +883,7 @@ class tform_base {
 	function encode($record, $tab, $dbencode = true) {
 		global $app;
 
-		if(!is_array($this->formDef['tabs'][$tab])) $app->error("Tab is empty or does not exist (TAB: $tab).");
+		if(!is_array($this->formDef['tabs'][$tab])) $app->error("Tab is empty or does not exist (TAB: ".$app->functions->htmlentities($tab).").");
 		return $this->_encode($record, $tab, $dbencode, false);
 	}
 
@@ -910,6 +927,12 @@ class tform_base {
 				case 'NOWHITESPACE':
 					$returnval = preg_replace('/\s+/', '', $returnval);
 					break;
+				case 'STRIPTAGS':
+					$returnval = strip_tags(preg_replace('/<script[^>]*?>.*?<\/script>/is', '', $returnval));
+					break;
+				case 'STRIPNL':
+					$returnval = str_replace(array("\n","\r"),'', $returnval);
+					break;
 				default:
 					$this->errorMessage .= "Unknown Filter: ".$filter['type'];
 					break;
@@ -1253,12 +1276,18 @@ class tform_base {
 		$this->action = $action;
 		$this->primary_id = $primary_id;
 
-
-		$record = $this->encode($record, $tab, true);
 		$sql_insert_key = '';
 		$sql_insert_val = '';
 		$sql_update = '';
 
+		$record = $this->encode($record, $tab, true);
+		
+		if(($this->primary_id_override > 0)) {
+			$sql_insert_key .= '`'.$this->formDef["db_table_idx"].'`, ';
+			$sql_insert_val .= $this->primary_id_override.", ";
+			$record['_primary_id'] = $this->primary_id_override;
+		}
+
 		if($api == true) $fields = &$this->formDef['fields'];
 		else $fields = &$this->formDef['tabs'][$tab]['fields'];
 
@@ -1370,7 +1399,7 @@ class tform_base {
 		} else {
 			if($this->formDef['auth'] == 'yes') {
 				if($primary_id != 0) {
-					if($api == true && $_SESSION["s"]["user"]["client_id"] > 0 && $_SESSION["s"]["user"]["iserid"] > 0 && $_SESSION["s"]["user"]["default_group"] > 0) {
+					if($api == true && $_SESSION["s"]["user"]["client_id"] > 0 && $_SESSION["s"]["user"]["userid"] > 0 && $_SESSION["s"]["user"]["default_group"] > 0) {
 						$sql_update .= '`sys_userid` = '.$this->sys_userid.', ';
 						$sql_update .= '`sys_groupid` = '.$this->sys_default_group.', ';
 					}
@@ -1423,7 +1452,7 @@ class tform_base {
 		}
 
 		if(!is_array($this->formDef)) $app->error("Form definition not found.");
-		if(!is_array($this->formDef['tabs'][$tab])) $app->error("The tab is empty or does not exist (TAB: $tab).");
+		if(!is_array($this->formDef['tabs'][$tab])) $app->error("The tab is empty or does not exist (TAB: ".$app->functions->htmlentities($tab).").");
 
 		return $this->_getSQL($record, $tab, $action, $primary_id, $sql_ext_where, false);
 	}
