@@ -92,6 +92,12 @@ $form["tabs"]['software_repo'] = array (
 				1 => array ( 'type' => 'UNIQUE',
 					'errmsg'=> 'repo_name_unique'),
 			),
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
@@ -108,6 +114,12 @@ $form["tabs"]['software_repo'] = array (
 				1 => array ( 'type' => 'UNIQUE',
 					'errmsg'=> 'repo_name_unique'),
 			),
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
@@ -119,6 +131,12 @@ $form["tabs"]['software_repo'] = array (
 		'repo_username' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
