@@ -63,7 +63,7 @@ $liste['item'][] = array( 'field'  => 'mail_server',
 	'prefix' => '%',
 	'suffix' => '%',
 	'width'  => '',
-	'value'  => array('1' => "<div id=\"ir-Yes\" class=\"swap\"><span>".$app->lng('yes_txt')."</span></div>", '0' => "<div class=\"swap\" id=\"ir-No\"><span>".$app->lng('no_txt')."</span></div>"));
+	'value'  => array('1' => $app->lng('yes_txt'), '0' => $app->lng('no_txt')));
 
 $liste['item'][] = array( 'field'  => 'web_server',
 	'datatype' => 'VARCHAR',
@@ -72,7 +72,7 @@ $liste['item'][] = array( 'field'  => 'web_server',
 	'prefix' => '%',
 	'suffix' => '%',
 	'width'  => '',
-	'value'  => array('1' => "<div id=\"ir-Yes\" class=\"swap\"><span>".$app->lng('yes_txt')."</span></div>", '0' => "<div class=\"swap\" id=\"ir-No\"><span>".$app->lng('no_txt')."</span></div>"));
+	'value'  => array('1' => $app->lng('yes_txt'), '0' => $app->lng('no_txt')));
 
 $liste['item'][] = array( 'field'  => 'dns_server',
 	'datatype' => 'VARCHAR',
@@ -81,7 +81,7 @@ $liste['item'][] = array( 'field'  => 'dns_server',
 	'prefix' => '%',
 	'suffix' => '%',
 	'width'  => '',
-	'value'  => array('1' => "<div id=\"ir-Yes\" class=\"swap\"><span>".$app->lng('yes_txt')."</span></div>", '0' => "<div class=\"swap\" id=\"ir-No\"><span>".$app->lng('no_txt')."</span></div>"));
+	'value'  => array('1' => $app->lng('yes_txt'), '0' => $app->lng('no_txt')));
 
 $liste['item'][] = array( 'field'  => 'file_server',
 	'datatype' => 'VARCHAR',
@@ -90,7 +90,7 @@ $liste['item'][] = array( 'field'  => 'file_server',
 	'prefix' => '%',
 	'suffix' => '%',
 	'width'  => '',
-	'value'  => array('1' => "<div id=\"ir-Yes\" class=\"swap\"><span>".$app->lng('yes_txt')."</span></div>", '0' => "<div class=\"swap\" id=\"ir-No\"><span>".$app->lng('no_txt')."</span></div>"));
+	'value'  => array('1' => $app->lng('yes_txt'), '0' => $app->lng('no_txt')));
 
 $liste['item'][] = array( 'field'  => 'db_server',
 	'datatype' => 'VARCHAR',
@@ -99,7 +99,7 @@ $liste['item'][] = array( 'field'  => 'db_server',
 	'prefix' => '%',
 	'suffix' => '%',
 	'width'  => '',
-	'value'  => array('1' => "<div id=\"ir-Yes\" class=\"swap\"><span>".$app->lng('yes_txt')."</span></div>", '0' => "<div class=\"swap\" id=\"ir-No\"><span>".$app->lng('no_txt')."</span></div>"));
+	'value'  => array('1' => $app->lng('yes_txt'), '0' => $app->lng('no_txt')));
 
 $liste['item'][] = array( 'field'  => 'vserver_server',
 	'datatype' => 'VARCHAR',
@@ -108,7 +108,7 @@ $liste['item'][] = array( 'field'  => 'vserver_server',
 	'prefix' => '%',
 	'suffix' => '%',
 	'width'  => '',
-	'value'  => array('1' => "<div id=\"ir-Yes\" class=\"swap\"><span>".$app->lng('yes_txt')."</span></div>", '0' => "<div class=\"swap\" id=\"ir-No\"><span>".$app->lng('no_txt')."</span></div>"));
+	'value'  => array('1' => $app->lng('yes_txt'), '0' => $app->lng('no_txt')));
 
 $liste['item'][] = array( 'field'  => 'xmpp_server',
 	'datatype' => 'VARCHAR',
@@ -117,6 +117,6 @@ $liste['item'][] = array( 'field'  => 'xmpp_server',
 	'prefix' => '%',
 	'suffix' => '%',
 	'width'  => '',
-	'value'  => array('1' => "<div id=\"ir-Yes\" class=\"swap\"><span>".$app->lng('yes_txt')."</span></div>", '0' => "<div class=\"swap\" id=\"ir-No\"><span>".$app->lng('no_txt')."</span></div>"));
+	'value'  => array('1' => $app->lng('yes_txt'), '0' => $app->lng('no_txt')));
 
 ?>
