@@ -91,6 +91,12 @@ $form["tabs"]['address'] = array (
 		'company_name' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
@@ -119,6 +125,10 @@ $form["tabs"]['address'] = array (
 			'searchable' => 1,
 			'filters'   => array( 0 => array( 'event' => 'SAVE',
 												'type' => 'TRIM'),
+								  1 => array( 'event' => 'SAVE',
+												'type' => 'STRIPTAGS'),
+								  2 => array( 'event' => 'SAVE',
+												'type' => 'STRIPNL')
 			),
 		),
 		'contact_name' => array (
@@ -137,6 +147,10 @@ $form["tabs"]['address'] = array (
 			'searchable' => 1,
 			'filters'   => array( 0 => array( 'event' => 'SAVE',
 												'type' => 'TRIM'),
+								  1 => array( 'event' => 'SAVE',
+												'type' => 'STRIPTAGS'),
+								  2 => array( 'event' => 'SAVE',
+												'type' => 'STRIPNL')
 			),
 		),
 		'customer_no' => array (
@@ -146,6 +160,12 @@ $form["tabs"]['address'] = array (
 					'errmsg'=> 'customer_no_error_unique',
 					'allowempty' => 'y'),
 			),
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
@@ -226,6 +246,12 @@ $form["tabs"]['address'] = array (
 		'street' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
@@ -238,6 +264,12 @@ $form["tabs"]['address'] = array (
 		'zip' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
@@ -250,6 +282,12 @@ $form["tabs"]['address'] = array (
 		'city' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
@@ -262,6 +300,12 @@ $form["tabs"]['address'] = array (
 		'state' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
@@ -285,6 +329,12 @@ $form["tabs"]['address'] = array (
 		'telephone' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
@@ -297,6 +347,12 @@ $form["tabs"]['address'] = array (
 		'mobile' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
@@ -309,6 +365,12 @@ $form["tabs"]['address'] = array (
 		'fax' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
@@ -345,6 +407,12 @@ $form["tabs"]['address'] = array (
 		'internet' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => 'http://',
 			'value'  => '',
 			'separator' => '',
@@ -357,6 +425,12 @@ $form["tabs"]['address'] = array (
 		'icq' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
@@ -385,12 +459,22 @@ $form["tabs"]['address'] = array (
 								1 => array( 	'event' => 'SAVE',
 												'type' => 'TOUPPER'),
 								2 => array( 	'event' => 'SAVE',
-												'type' => 'NOWHITESPACE')
+												'type' => 'NOWHITESPACE'),
+								3 => array( 	'event' => 'SAVE',
+												'type' => 'STRIPTAGS'),
+								4 => array( 	'event' => 'SAVE',
+												'type' => 'STRIPNL')
 			),
 		),
 		'company_id' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
@@ -402,6 +486,12 @@ $form["tabs"]['address'] = array (
 		'bank_account_owner' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
@@ -413,6 +503,12 @@ $form["tabs"]['address'] = array (
 		'bank_account_number' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
@@ -424,6 +520,12 @@ $form["tabs"]['address'] = array (
 		'bank_code' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
@@ -435,6 +537,12 @@ $form["tabs"]['address'] = array (
 		'bank_name' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
@@ -458,7 +566,11 @@ $form["tabs"]['address'] = array (
 								1 => array( 	'event' => 'SAVE',
 												'type' => 'TOUPPER'),
 								2 => array( 	'event' => 'SAVE',
-												'type' => 'NOWHITESPACE')
+												'type' => 'NOWHITESPACE'),
+								3 => array( 	'event' => 'SAVE',
+												'type' => 'STRIPTAGS'),
+								4 => array( 	'event' => 'SAVE',
+												'type' => 'STRIPNL')
 			),
 		),
 		'bank_account_swift' => array (
@@ -476,12 +588,20 @@ $form["tabs"]['address'] = array (
 								1 => array( 	'event' => 'SAVE',
 												'type' => 'TOUPPER'),
 								2 => array( 	'event' => 'SAVE',
-												'type' => 'NOWHITESPACE')
+												'type' => 'NOWHITESPACE'),
+								3 => array( 	'event' => 'SAVE',
+												'type' => 'STRIPTAGS'),
+								4 => array( 	'event' => 'SAVE',
+												'type' => 'STRIPNL')
 			),
 		),
 		'notes' => array (
 			'datatype' => 'TEXT',
 			'formtype' => 'TEXTAREA',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS')
+			),
 			'default' => '',
 			'value'  => '',
 			'separator' => '',
@@ -538,6 +658,12 @@ $form["tabs"]['address'] = array (
 		'added_by' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
 			'default' => $_SESSION['s']['user']['username'],
 			'value'  => '',
 			'separator' => '',
@@ -961,7 +1087,7 @@ $form["tabs"]['limits'] = array (
 			),
 			'default' => '',
 			'separator' => ',',
-			'valuelimit' => 'client:web_php_options',
+			'valuelimit' => 'system:sites:web_php_options',
 			'value'  => array('no' => 'Disabled', 'fast-cgi' => 'Fast-CGI', 'cgi' => 'CGI', 'mod' => 'Mod-PHP', 'suphp' => 'SuPHP', 'php-fpm' => 'PHP-FPM', 'hhvm' => 'HHVM')
 		),
 		'limit_cgi' => array (
