@@ -37,9 +37,9 @@ $app->auth->check_module_permissions('dashboard');
 if(isset($_GET['hide'])) {
 	if($_GET['hide'] == 'donate') {
 		$timeout = time()+31536000;
-		$tmp = $app->db->queryOneRecord("SELECT value FROM sys_config WHERE group = 'interface' AND name = 'hide_donation_dashlet'");
+		$tmp = $app->db->queryOneRecord("SELECT `value` FROM `sys_config` WHERE `group` = 'interface' AND `name` = 'hide_donation_dashlet'");
 		if(is_array($tmp)) {
-			$app->db->query("UPDATE sys_config SET value = ? WHERE group = 'interface' AND name = 'hide_donation_dashlet')",$timeout);
+			$app->db->query("UPDATE `sys_config` SET `value` = ? WHERE `group` = 'interface' AND `name` = 'hide_donation_dashlet'",$timeout);
 		} else {
 			$app->db->query("INSERT INTO `sys_config` (`group`,`name`,`value`) VALUES ('interface','hide_donation_dashlet',?)",$timeout);
 		}
@@ -51,7 +51,7 @@ $app->uses('tpl');
 $app->tpl->newTemplate("templates/dashboard.htm");
 
 //* load language file
-$lng_file = 'lib/lang/'.$_SESSION['s']['language'].'.lng';
+$lng_file = 'lib/lang/'.$app->functions->check_language($_SESSION['s']['language']).'.lng';
 include $lng_file;
 $app->tpl->setVar($wb);
 
@@ -121,7 +121,7 @@ if(isset($_SESSION['show_error_msg'])) {
 */
 if($_SESSION["s"]["user"]["typ"] == 'admin') {
 	if(!isset($_SESSION['s']['new_ispconfig_version'])) {
-		$new_version = @file_get_contents('http://www.ispconfig.org/downloads/ispconfig3_version.txt');
+		$new_version = @file_get_contents('https://www.ispconfig.org/downloads/ispconfig3_version.txt');
 		$_SESSION['s']['new_ispconfig_version'] = trim($new_version);
 	}
 	$v1 = ISPC_APP_VERSION;
