@@ -6,7 +6,7 @@ require_once '../../lib/app.inc.php';
 $list_def_file = "list/faq_manage_questions_list.php";
 
 //* Check permissions for module
-$app->auth->check_module_permissions('help');
+$app->auth->check_module_permissions('admin');
 
 //* Loading the class
 $app->uses('listform_actions');
