@@ -1,5 +1,7 @@
 <?php
 
+die('deprecated');
+
 /*
 	Form Definition
 
@@ -106,7 +108,13 @@ $form["tabs"]['spamfilter'] = array (
 		'spam_rewrite_subject' => array (
 			'datatype' => 'VARCHAR',
 			'formtype' => 'TEXT',
-			'default' => '***SPAM***',
+			'filters'   => array(
+					0 => array( 'event' => 'SAVE',
+					'type' => 'STRIPTAGS'),
+					1 => array( 'event' => 'SAVE',
+					'type' => 'STRIPNL')
+			),
+			'default' => '***SPAM*** ',
 			'value'  => '',
 			'width'  => '30',
 			'maxlength' => '255'
