@@ -1,6 +1,6 @@
 <?php
-require_once('../../lib/config.inc.php');
-require_once('../../lib/app.inc.php');
+require_once '../../lib/config.inc.php';
+require_once '../../lib/app.inc.php';
 
 /******************************************
 * Begin Form configuration
@@ -21,7 +21,8 @@ $app->uses('listform_actions');
 // Limit the results to alias domains
 // $app->listform_actions->SQLExtWhere = "type = 'local'";
 
+$app->listform_actions->SQLOrderBy = 'ORDER BY mail_domain.domain';
 $app->listform_actions->onLoad();
 
 
-?>
\ No newline at end of file
+?>
