@@ -39,8 +39,8 @@ $tform_def_file = "form/mail_user.tform.php";
 * End Form configuration
 ******************************************/
 
-require_once('../../lib/config.inc.php');
-require_once('../../lib/app.inc.php');
+require_once '../../lib/config.inc.php';
+require_once '../../lib/app.inc.php';
 
 //* Check permissions for module
 $app->auth->check_module_permissions('mail');
@@ -53,14 +53,22 @@ class page_action extends tform_actions {
 
 	function onBeforeDelete() {
 		global $app; $conf;
-			
-			$tmp_user = $app->db->queryOneRecord("SELECT id FROM spamfilter_users WHERE email = '".mysql_real_escape_string($this->dataRecord["email"])."'");
-			$app->db->datalogDelete('spamfilter_users', 'id', $tmp_user["id"]);
-			
+
+		$tmp_user = $app->db->queryOneRecord("SELECT id FROM spamfilter_users WHERE email = ?", $this->dataRecord["email"]);
+		$app->db->datalogDelete('spamfilter_users', 'id', $tmp_user["id"]);
+
+		$tmp_filters = $app->db->queryAllRecords("SELECT filter_id FROM mail_user_filter WHERE mailuser_id = ?", $this->id);
+		if(is_array($tmp_filters)) {
+			foreach($tmp_filters as $tmp) {
+				$app->db->datalogDelete('mail_user_filter', 'filter_id', $tmp["filter_id"]);
+			}
 		}
+
+	}
+
 }
 
 $page = new page_action;
 $page->onDelete();
 
-?>
\ No newline at end of file
+?>
