@@ -28,8 +28,8 @@ NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-require_once('../../lib/config.inc.php');
-require_once('../../lib/app.inc.php');
+require_once '../../lib/config.inc.php';
+require_once '../../lib/app.inc.php';
 
 /******************************************
 * Begin Form configuration
@@ -44,12 +44,32 @@ $list_def_file = "list/ftp_user.list.php";
 //* Check permissions for module
 $app->auth->check_module_permissions('sites');
 
-$app->uses('listform_actions');
-
-// Limit the results to alias domains
-//$app->listform_actions->SQLExtWhere = "type = 'subdomain'";
-
-$app->listform_actions->onLoad();
+$app->load('listform_actions');
 
 
-?>
\ No newline at end of file
+class list_action extends listform_actions {
+
+	function onShow() {
+		global $app, $conf;
+
+		$app->uses('getconf');
+		$global_config = $app->getconf->get_global_config('sites');
+
+		if($global_config['webftp_url'] != '') {
+			$app->tpl->setVar('webftp_link', 1);
+			$app->tpl->setVar('webftp_url', $global_config['webftp_url']);
+		} else {
+			$app->tpl->setVar('webftp_link', 0);
+		}
+
+		parent::onShow();
+	}
+
+}
+
+$list = new list_action;
+$list->SQLOrderBy = 'ORDER BY ftp_user.username';
+$list->onLoad();
+
+
+?>
