@@ -29,8 +29,8 @@ try {
 		'cc' => '',
 		'homedir' => '/var/vmail',
 		'autoresponder' => 'n',
-		'autoresponder_start_date' => array('day' => 1, 'month' => 7, 'year' => 2012, 'hour' => 0, 'minute' => 0),
-		'autoresponder_end_date' => array('day' => 20, 'month' => 7, 'year' => 2012, 'hour' => 0, 'minute' => 0),
+		'autoresponder_start_date' => '',
+		'autoresponder_end_date' => '',
 		'autoresponder_text' => 'hallo',
 		'move_junk' => 'n',
 		'custom_mailfilter' => 'spam',
