@@ -31,35 +31,44 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class getconf {
 
 	var $config;
-	
+
 	function get_server_config($server_id, $section = '') {
 		global $app;
-		
+
 		if(!is_array($this->config[$server_id])) {
 			$app->uses('ini_parser');
 			$server_id = intval($server_id);
-			$server = $app->db->queryOneRecord("SELECT config FROM server WHERE server_id = $server_id");
-			$this->config[$server_id] = $app->ini_parser->parse_ini_string(stripslashes($server["config"]));
+			$server = $app->db->queryOneRecord('SELECT config FROM server WHERE server_id = ?', $server_id);
+			$this->config[$server_id] = $app->ini_parser->parse_ini_string(stripslashes($server['config']));
 		}
-		
+
 		if($section == '') {
 			return $this->config[$server_id];
 		} else {
 			return $this->config[$server_id][$section];
 		}
 	}
-	
+
 	public function get_global_config($section = '') {
 		global $app;
-		
-		if(!is_array($this->config['global'])) {
+
+		if(!@is_array($this->config['global'])) {
 			$app->uses('ini_parser');
-			$tmp = $app->db->queryOneRecord("SELECT config FROM sys_ini WHERE sysini_id = 1");
-			$this->config['global'] = $app->ini_parser->parse_ini_string(stripslashes($tmp["config"]));
+			$tmp = $app->db->queryOneRecord('SELECT config FROM sys_ini WHERE sysini_id = 1');
+			$this->config['global'] = $app->ini_parser->parse_ini_string(stripslashes($tmp['config']));
 		}
 		return ($section == '') ? $this->config['global'] : $this->config['global'][$section];
 	}
 	
+	public function get_security_config($section = '') {
+		global $app;
+
+		$app->uses('ini_parser');
+		$security_config = $app->ini_parser->parse_ini_string(file_get_contents('/usr/local/ispconfig/security/security_settings.ini'));
+
+		return ($section == '') ? $security_config : $security_config[$section];
+	}
+
 }
 
-?>
\ No newline at end of file
+?>
