@@ -73,7 +73,23 @@ class mysql_clientdb_plugin {
 
 	function process_host_list($action, $database_name, $database_user, $database_password, $host_list, $link, $database_rename_user = '', $user_access_mode = 'rw') {
 		global $app;
-		
+
+		// check mysql-plugins
+		$unwanted_sql_plugins = array('validate_password'); // strict-password-validation
+		$temp = "'".implode("','", $unwanted_sql_plugins)."'";
+		$result = $link->query("SELECT plugin_name FROM information_schema.plugins WHERE plugin_status='ACTIVE' AND plugin_name IN ($temp)");
+		if($result && $result->num_rows > 0) {
+			$sql_plugins = array();
+			while ($row = $result->fetch_assoc()) {
+				$sql_plugins[] = $row['plugin_name'];
+			}
+			$result->free();
+			if(count($sql_plugins) > 0) {
+				foreach ($sql_plugins as $plugin) $app->log("MySQL-Plugin $plugin enabled - can not execute function process_host_list", LOGLEVEL_ERROR);
+				return false;
+			}
+		}
+
 		if(!$user_access_mode) $user_access_mode = 'rw';
 		$action = strtoupper($action);
 
@@ -278,6 +294,12 @@ class mysql_clientdb_plugin {
 				return;
 			}
 			
+			// check if the database exists
+			if($data['new']['database_name'] == $data['old']['database_name']) {
+				$result = $link->query("SHOW DATABASES LIKE '".$link->escape_string($data['new']['database_name'])."'");
+				if($result->num_rows === 0) $this->db_insert($event_name, $data);
+			}
+
 			// get the users for this database
 			$db_user = $app->db->queryOneRecord("SELECT `database_user`, `database_password` FROM `web_database_user` WHERE `database_user_id` = ?", $data['new']['database_user_id']);
 			$old_db_user = $app->db->queryOneRecord("SELECT `database_user`, `database_password` FROM `web_database_user` WHERE `database_user_id` = ?", $data['old']['database_user_id']);
@@ -309,6 +331,7 @@ class mysql_clientdb_plugin {
 				$timestamp = time();
 
 				$tables = $link->query("SELECT TABLE_NAME FROM information_schema.tables WHERE table_schema='".$old_name."' AND TABLE_TYPE='BASE TABLE'");
+				$tables_all = $link->query("SELECT TABLE_NAME FROM information_schema.tables WHERE table_schema='".$old_name."'");
 				if ($tables->num_rows > 0) {
 					while ($row = $tables->fetch_assoc()) {
 						$tables_array[] = $row['TABLE_NAME'];
@@ -321,15 +344,15 @@ class mysql_clientdb_plugin {
 							$triggers_array[] = $row;
 						}
 						$app->log('Dumping triggers from '.$old_name, LOGLEVEL_DEBUG);
-						$command = "mysqldump -h ".escapeshellarg($clientdb_host)." -u ".escapeshellarg($clientdb_user)." -p".escapeshellarg($clientdb_password)." ".$old_name." -d -t -R -E > ".$timestamp.$old_name.'.triggers';
-						exec($command, $out, $ret);
+						$command = "mysqldump -h ? -u ? -p? ? -d -t -R -E > ?";
+						$app->system->exec_safe($command, $clientdb_host, $clientdb_user, $clientdb_password, $old_name, $timestamp.$old_name.'.triggers');
+						$ret = $app->system->last_exec_retcode();
 						$app->system->chmod($timestamp.$old_name.'.triggers', 0600);
 						if ($ret != 0) {
 							unset($triggers_array);
 							$app->system->unlink($timestamp.$old_name.'.triggers');
 							$app->log('Unable to dump triggers from '.$old_name, LOGLEVEL_ERROR);
 						}
-						unset($out);
 					}
 
 					//* save views
@@ -343,15 +366,15 @@ class mysql_clientdb_plugin {
 						}
 						$app->log('Dumping views from '.$old_name, LOGLEVEL_DEBUG);
 						$temp_views = implode(' ', $temp);
-						$command = "mysqldump -h ".escapeshellarg($clientdb_host)." -u ".escapeshellarg($clientdb_user)." -p".escapeshellarg($clientdb_password)." ".$old_name." ".$temp_views." > ".$timestamp.$old_name.'.views';
-						exec($command, $out, $ret);
+						$command = "mysqldump -h ? -u ? -p? ? ? > ?";
+						$app->system->exec_safe($command, $clientdb_host, $clientdb_user, $clientdb_password, $old_name, $temp_views, $timestamp.$old_name.'.views');
+						$ret = $app->system->last_exec_retcode();
 						$app->system->chmod($timestamp.$old_name.'.views', 0600);
 						if ($ret != 0) {
 							unset($views_array);
 							$app->system->unlink($timestamp.$old_name.'.views');
 							$app->log('Unable to dump views from '.$old_name, LOGLEVEL_ERROR);
 						}
-						unset($out);
 						unset($temp);
 						unset($temp_views);
 					}
@@ -382,8 +405,9 @@ class mysql_clientdb_plugin {
 								unset($_trigger);
 							}
 							//* update triggers, routines and events
-							$command = "mysql -h ".escapeshellarg($clientdb_host)." -u ".escapeshellarg($clientdb_user)." -p".escapeshellarg($clientdb_password)." ".$new_name." < ".$timestamp.$old_name.'.triggers';
-							exec($command, $out, $ret);
+							$command = "mysql -h ? -u ? -p? ? < ?";
+							$app->system->exec_safe($command, $clientdb_host, $clientdb_user, $clientdb_password, $new_name, $timestamp.$old_name.'.triggers');
+							$ret = $app->system->last_exec_retcode();
 							if ($ret != 0) {
 								$app->log('Unable to import triggers for '.$new_name, LOGLEVEL_ERROR);
 							} else {
@@ -393,8 +417,9 @@ class mysql_clientdb_plugin {
 
 						//* loading views
 						if (@is_array($views_array)) {
-							$command = "mysql -h ".escapeshellarg($clientdb_host)." -u ".escapeshellarg($clientdb_user)." -p".escapeshellarg($clientdb_password)." ".$new_name." < ".$timestamp.$old_name.'.views';
-							exec($command, $out, $ret);
+							$command = "mysql -h ? -u ? -p? ? < ?";
+							$app->system->exec_safe($command, $clientdb_host, $clientdb_user, $clientdb_password, $new_name, $timestamp.$old_name.'.views');
+							$ret = $app->system->last_exec_retcode();
 							if ($ret != 0) {
 								$app->log('Unable to import views for '.$new_name, LOGLEVEL_ERROR);
 							} else {
@@ -414,6 +439,11 @@ class mysql_clientdb_plugin {
 						}
 					}
 
+				} elseif ($tables->num_rows == 0 && $tables_all->num_rows == 0) {
+					//* Rename empty database by creating a new one and dropping the old database
+					$this->db_insert($event_name, $data);
+					$this->db_delete($event_name, $data);
+
 				} else { //* SELECT TABLE_NAME error
 					$app->log('Unable to rename database '.$old_name.' to '.$new_name, LOGLEVEL_ERROR);
 				}
@@ -482,7 +512,7 @@ class mysql_clientdb_plugin {
 							$app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
 						} else {
 							// Find out users to drop and users to revoke
-							$drop_or_revoke_user = $this->drop_or_revoke_user($data['old']['database_id'], $data['old']['database_user_id'], $old_host_list);
+							$drop_or_revoke_user = $this->drop_or_revoke_user($data['old']['database_id'], $data['old']['database_ro_user_id'], $old_host_list);
 							if($drop_or_revoke_user['drop_hosts'] != '') $this->process_host_list('DROP', $data['old']['database_name'], $old_db_ro_user['database_user'], $old_db_ro_user['database_password'], $drop_or_revoke_user['drop_hosts'], $link);
 							if($drop_or_revoke_user['revoke_hosts'] != '') $this->process_host_list('REVOKE', $data['old']['database_name'], $old_db_ro_user['database_user'], $old_db_ro_user['database_password'], $drop_or_revoke_user['revoke_hosts'], $link);
 						}
@@ -558,7 +588,7 @@ class mysql_clientdb_plugin {
 						$app->log('User root not allowed for Client databases', LOGLEVEL_WARNING);
 					} else {
 						// Find out users to drop and users to revoke
-						$drop_or_revoke_user = $this->drop_or_revoke_user($data['old']['database_id'], $data['old']['database_user_id'], $data['old']['remote_ips']);
+						$drop_or_revoke_user = $this->drop_or_revoke_user($data['old']['database_id'], $data['old']['database_ro_user_id'], $data['old']['remote_ips']);
 						if($drop_or_revoke_user['drop_hosts'] != '') $this->process_host_list('DROP', $data['old']['database_name'], $old_db_ro_user['database_user'], $old_db_ro_user['database_password'], $drop_or_revoke_user['drop_hosts'], $link);
 						if($drop_or_revoke_user['revoke_hosts'] != '') $this->process_host_list('REVOKE', $data['old']['database_name'], $old_db_ro_user['database_user'], $old_db_ro_user['database_password'], $drop_or_revoke_user['revoke_hosts'], $link);
 					}
@@ -680,8 +710,26 @@ class mysql_clientdb_plugin {
 			}
 
 			if($data['new']['database_password'] != $data['old']['database_password'] && $data['new']['database_password'] != '') {
-				$link->query("SET PASSWORD FOR '".$link->escape_string($data['new']['database_user'])."'@'$db_host' = '".$link->escape_string($data['new']['database_password'])."';");
-				$app->log('Changing MySQL user password for: '.$data['new']['database_user'].'@'.$db_host, LOGLEVEL_DEBUG);
+				$result = $app->db->queryOneRecord("SELECT VERSION() as version");
+				$dbversion = $result['version'];
+
+				// mariadb or mysql < 5.7
+				if(stripos($dbversion, 'mariadb') !== false || version_compare($dbversion, '5.7', '<')) {
+					$query = sprintf("SET PASSWORD FOR '%s'@'%s' = '%s'",
+						$link->escape_string($data['new']['database_user']),
+						$db_host,
+						$link->escape_string($data['new']['database_password']));
+					$link->query($query);
+				}
+				// mysql >= 5.7
+				else {
+					$query = sprintf("ALTER USER IF EXISTS '%s'@'%s' IDENTIFIED WITH mysql_native_password AS '%s'",
+						$link->escape_string($data['new']['database_user']),
+						$db_host,
+						$link->escape_string($data['new']['database_password']));
+					$link->query($query);
+				}
+				$app->log('Changing MySQL user password for: ' . $data['new']['database_user'] . '@' . $db_host, LOGLEVEL_DEBUG);
 			}
 		}
 
