@@ -115,34 +115,36 @@ class shelluser_base_plugin {
 				
 				// Create home base directory if it does not exist
 				if(!is_dir($data['new']['dir'].'/home')){
-					$app->file->mkdirs(escapeshellcmd($data['new']['dir'].'/home'), '0755');
+					$app->file->mkdirs($data['new']['dir'].'/home', '0755');
 				}
 				
 				// Change ownership of home base dir to root user
-				$app->system->chown(escapeshellcmd($data['new']['dir'].'/home'),'root');
-				$app->system->chgrp(escapeshellcmd($data['new']['dir'].'/home'),'root');
-				$app->system->chmod(escapeshellcmd($data['new']['dir'].'/home'),0755);
+				$app->system->chown($data['new']['dir'].'/home','root');
+				$app->system->chgrp($data['new']['dir'].'/home','root');
+				$app->system->chmod($data['new']['dir'].'/home',0755);
 				
 				if(!is_dir($homedir)){
-					$app->file->mkdirs(escapeshellcmd($homedir), '0750');
-					$app->system->chown(escapeshellcmd($homedir),escapeshellcmd($data['new']['puser']),false);
-					$app->system->chgrp(escapeshellcmd($homedir),escapeshellcmd($data['new']['pgroup']),false);
+					$app->file->mkdirs($homedir, '0750');
+					$app->system->chown($homedir,$data['new']['puser'],false);
+					$app->system->chgrp($homedir,$data['new']['pgroup'],false);
 				}
-				$command = 'useradd';
-				$command .= ' -d '.escapeshellcmd($homedir);
-				$command .= ' -g '.escapeshellcmd($data['new']['pgroup']);
-				$command .= ' -o '; // non unique
-				if($data['new']['password'] != '') $command .= ' -p '.escapeshellcmd($data['new']['password']);
-				$command .= ' -s '.escapeshellcmd($data['new']['shell']);
-				$command .= ' -u '.escapeshellcmd($uid);
-				$command .= ' '.escapeshellcmd($data['new']['username']);
-
-				exec($command);
+				$command = 'useradd -d ? -g ? -o'; // non unique
+				$command .= ' -s ? -u ? ?';
+				$app->system->exec_safe($command, $homedir, $data['new']['pgroup'], $data['new']['shell'], $uid, $data['new']['username']);
 				$app->log("Executed command: ".$command, LOGLEVEL_DEBUG);
 				$app->log("Added shelluser: ".$data['new']['username'], LOGLEVEL_DEBUG);
-				
-				$app->system->chown(escapeshellcmd($data['new']['dir']),escapeshellcmd($data['new']['username']),false);
-				$app->system->chgrp(escapeshellcmd($data['new']['dir']),escapeshellcmd($data['new']['pgroup']),false);
+
+				if($data['new']['password'] != '') {
+					$retval = null;
+					$stderr = '';
+					$app->system->pipe_exec('chpasswd -e ' . escapeshellarg($data['new']['username']), $data['new']['username'] . ':' . $data['new']['password'], $retval, $stderr);
+					if($retval != 0) {
+						$app->log("Command chpasswd failed for user ".$data['new']['username'] . ' with code ' . $retval . ': ' . $stderr, LOGLEVEL_WARN);
+					}
+				}
+			
+				$app->system->chown($data['new']['dir'],$data['new']['username'],false);
+				$app->system->chgrp($data['new']['dir'],$data['new']['pgroup'],false);
 				
 
 				// call the ssh-rsa update function
@@ -152,21 +154,21 @@ class shelluser_base_plugin {
 				$this->_setup_ssh_rsa();
 
 				//* Create .bash_history file
-				$app->system->touch(escapeshellcmd($homedir).'/.bash_history');
-				$app->system->chmod(escapeshellcmd($homedir).'/.bash_history', 0750);
-				$app->system->chown(escapeshellcmd($homedir).'/.bash_history', $data['new']['username']);
-				$app->system->chgrp(escapeshellcmd($homedir).'/.bash_history', $data['new']['pgroup']);
+				$app->system->touch($homedir.'/.bash_history');
+				$app->system->chmod($homedir.'/.bash_history', 0750);
+				$app->system->chown($homedir.'/.bash_history', $data['new']['username']);
+				$app->system->chgrp($homedir.'/.bash_history', $data['new']['pgroup']);
 
 				//* Create .profile file
-				$app->system->touch(escapeshellcmd($homedir).'/.profile');
-				$app->system->chmod(escapeshellcmd($homedir).'/.profile', 0644);
-				$app->system->chown(escapeshellcmd($homedir).'/.profile', $data['new']['username']);
-				$app->system->chgrp(escapeshellcmd($homedir).'/.profile', $data['new']['pgroup']);
+				$app->system->touch($homedir.'/.profile');
+				$app->system->chmod($homedir.'/.profile', 0644);
+				$app->system->chown($homedir.'/.profile', $data['new']['username']);
+				$app->system->chgrp($homedir.'/.profile', $data['new']['pgroup']);
 
 				//* Disable shell user temporarily if we use jailkit
 				if($data['new']['chroot'] == 'jailkit') {
-					$command = 'usermod -s /bin/false -L '.escapeshellcmd($data['new']['username']).' 2>/dev/null';
-					exec($command);
+					$command = 'usermod -s /bin/false -L ? 2>/dev/null';
+					$app->system->exec_safe($command, $data['new']['username']);
 					$app->log("Disabling shelluser temporarily: ".$command, LOGLEVEL_DEBUG);
 				}
 
@@ -226,48 +228,39 @@ class shelluser_base_plugin {
 					$homedir_old = $data['old']['dir'].'/home/'.$data['old']['username'];
 				}
 				
+				$app->log("Homedir New: ".$homedir, LOGLEVEL_DEBUG);
+				$app->log("Homedir Old: ".$homedir_old, LOGLEVEL_DEBUG);
+				
 				// Check if the user that we want to update exists, if not, we insert it
 				if($app->system->is_user($data['old']['username'])) {
 					//* Remove webfolder protection
 					$app->system->web_folder_protection($web['document_root'], false);
-					
-					/*
-					$command = 'usermod';
-					$command .= ' --home '.escapeshellcmd($data['new']['dir']);
-					$command .= ' --gid '.escapeshellcmd($data['new']['pgroup']);
-					// $command .= ' --non-unique ';
-					$command .= ' --password '.escapeshellcmd($data['new']['password']);
-					if($data['new']['chroot'] != 'jailkit') $command .= ' --shell '.escapeshellcmd($data['new']['shell']);
-					// $command .= ' --uid '.escapeshellcmd($uid);
-					$command .= ' --login '.escapeshellcmd($data['new']['username']);
-					$command .= ' '.escapeshellcmd($data['old']['username']);
 
-					exec($command);
-					$app->log("Executed command: $command ",LOGLEVEL_DEBUG);
-					*/
-					//$groupinfo = $app->system->posix_getgrnam($data['new']['pgroup']);
-					if($homedir != $homedir_old && !is_dir($homedir)){
+					if($homedir != $homedir_old){
 						$app->system->web_folder_protection($web['document_root'], false);
-						if(!is_dir($data['new']['dir'].'/home')){
-							$app->file->mkdirs(escapeshellcmd($data['new']['dir'].'/home'), '0750');
-							$app->system->chown(escapeshellcmd($data['new']['dir'].'/home'),escapeshellcmd($data['new']['puser']));
-							$app->system->chgrp(escapeshellcmd($data['new']['dir'].'/home'),escapeshellcmd($data['new']['pgroup']));
+						// Rename dir, in case the new directory exists already.
+						if(is_dir($homedir)) {
+							$app->log("New Homedir exists, renaming it to ".$homedir.'_bak', LOGLEVEL_DEBUG);
+							$app->system->rename($homedir,$homedir.'_bak');
 						}
-						$app->file->mkdirs(escapeshellcmd($homedir), '0755');
-						$app->system->chown(escapeshellcmd($homedir),'root');
-						$app->system->chgrp(escapeshellcmd($homedir),'root');
+						
+						// Move old directory to new path
+						$app->system->rename($homedir_old,$homedir);
+						$app->file->mkdirs($homedir, '0750');
+						$app->system->chown($homedir,$data['new']['puser']);
+						$app->system->chgrp($homedir,$data['new']['pgroup']);
 						$app->system->web_folder_protection($web['document_root'], true);
 					} else {
 						if(!is_dir($homedir)){
 							$app->system->web_folder_protection($web['document_root'], false);
 							if(!is_dir($data['new']['dir'].'/home')){
-								$app->file->mkdirs(escapeshellcmd($data['new']['dir'].'/home'), '0755');
-								$app->system->chown(escapeshellcmd($data['new']['dir'].'/home'),'root');
-								$app->system->chgrp(escapeshellcmd($data['new']['dir'].'/home'),'root');
+								$app->file->mkdirs($data['new']['dir'].'/home', '0755');
+								$app->system->chown($data['new']['dir'].'/home','root');
+								$app->system->chgrp($data['new']['dir'].'/home','root');
 							}
-							$app->file->mkdirs(escapeshellcmd($homedir), '0750');
-							$app->system->chown(escapeshellcmd($homedir),escapeshellcmd($data['new']['puser']));
-							$app->system->chgrp(escapeshellcmd($homedir),escapeshellcmd($data['new']['pgroup']));
+							$app->file->mkdirs($homedir, '0750');
+							$app->system->chown($homedir,$data['new']['puser']);
+							$app->system->chgrp($homedir,$data['new']['pgroup']);
 							$app->system->web_folder_protection($web['document_root'], true);
 						}
 					}
@@ -282,18 +275,18 @@ class shelluser_base_plugin {
 
 					//* Create .bash_history file
 					if(!is_file($data['new']['dir']).'/.bash_history') {
-						$app->system->touch(escapeshellcmd($homedir).'/.bash_history');
-						$app->system->chmod(escapeshellcmd($homedir).'/.bash_history', 0750);
-						$app->system->chown(escapeshellcmd($homedir).'/.bash_history', escapeshellcmd($data['new']['username']));
-						$app->system->chgrp(escapeshellcmd($homedir).'/.bash_history', escapeshellcmd($data['new']['pgroup']));
+						$app->system->touch($homedir.'/.bash_history');
+						$app->system->chmod($homedir.'/.bash_history', 0750);
+						$app->system->chown($homedir.'/.bash_history', $data['new']['username']);
+						$app->system->chgrp($homedir.'/.bash_history', $data['new']['pgroup']);
 					}
 					
 					//* Create .profile file
 					if(!is_file($data['new']['dir']).'/.profile') {
-						$app->system->touch(escapeshellcmd($homedir).'/.profile');
-						$app->system->chmod(escapeshellcmd($homedir).'/.profile', 0644);
-						$app->system->chown(escapeshellcmd($homedir).'/.profile', escapeshellcmd($data['new']['username']));
-						$app->system->chgrp(escapeshellcmd($homedir).'/.profile', escapeshellcmd($data['new']['pgroup']));
+						$app->system->touch($homedir.'/.profile');
+						$app->system->chmod($homedir.'/.profile', 0644);
+						$app->system->chown($homedir.'/.profile', $data['new']['username']);
+						$app->system->chgrp($homedir.'/.profile', $data['new']['pgroup']);
 					}
 
 					//* Add webfolder protection again
@@ -348,7 +341,7 @@ class shelluser_base_plugin {
 						if(is_file($homedir . $delfile) && fileowner($homedir . $delfile) == $userid) unlink($homedir . $delfile);
 					}
 					foreach($dirs as $deldir) {
-						if(is_dir($homedir . $deldir) && fileowner($homedir . $deldir) == $userid) exec('rm -rf ' . escapeshellarg($homedir . $deldir));
+						if(is_dir($homedir . $deldir) && fileowner($homedir . $deldir) == $userid) $app->system->exec_safe('rm -rf ?', $homedir . $deldir);
 					}
 					$empty = true;
 					$dirres = opendir($homedir);
@@ -387,9 +380,8 @@ class shelluser_base_plugin {
 							$app->services->restartService('php-fpm', 'stop:'.$conf['init_scripts'].'/'.$web_config['php_fpm_init_script']);
 						}
 					}
-					$command = 'killall -u '.escapeshellcmd($data['old']['username']).' ; userdel -f';
-					$command .= ' '.escapeshellcmd($data['old']['username']).' &> /dev/null';
-					exec($command);
+					$command = 'killall -u ? ; userdel -f ? &> /dev/null';
+					$app->system->exec_safe($command, $data['old']['username'], $data['old']['username']);
 					$app->log("Deleted shelluser: ".$data['old']['username'], LOGLEVEL_DEBUG);
 					// start PHP-FPM again
 					if($web['php'] == 'php-fpm'){
@@ -433,12 +425,10 @@ class shelluser_base_plugin {
 			}
 		}
 		$sshrsa = trim($sshrsa);
-		$usrdir = escapeshellcmd($this->data['new']['dir']);
+		$usrdir = $this->data['new']['dir'];
 		//* Home directory of the new shell user
-		if($this->data['new']['chroot'] == 'jailkit') {
-			$usrdir = escapeshellcmd($this->data['new']['dir']);
-		} else {
-			$usrdir = escapeshellcmd($this->data['new']['dir'].'/home/'.$this->data['new']['username']);
+		if($this->data['new']['chroot'] != 'jailkit') {
+			$usrdir = $this->data['new']['dir'].'/home/'.$this->data['new']['username'];
 		}
 		$sshdir = $usrdir.'/.ssh';
 		$sshkeys= $usrdir.'/.ssh/authorized_keys';
@@ -461,7 +451,7 @@ class shelluser_base_plugin {
 			if(is_file('/root/.ssh/authorized_keys')) $app->system->file_put_contents($sshkeys, $app->system->file_get_contents('/root/.ssh/authorized_keys'));
 
 			// Remove duplicate keys
-			$existing_keys = @file($sshkeys);
+			$existing_keys = @file($sshkeys, FILE_IGNORE_NEW_LINES);
 			$new_keys = explode("\n", $userkey);
 			$final_keys_arr = @array_merge($existing_keys, $new_keys);
 			$new_final_keys_arr = array();
@@ -479,7 +469,7 @@ class shelluser_base_plugin {
 		}
 
 		//* Get the keys
-		$existing_keys = file($sshkeys);
+		$existing_keys = file($sshkeys, FILE_IGNORE_NEW_LINES);
 		$new_keys = explode("\n", $sshrsa);
 		$old_keys = explode("\n", $this->data['old']['ssh_rsa']);
 
@@ -487,7 +477,9 @@ class shelluser_base_plugin {
 		if(is_array($old_keys)) {
 			foreach($old_keys as $key => $val) {
 				$k = array_search(trim($val), $existing_keys);
-				unset($existing_keys[$k]);
+				if ($k !== false) {
+					unset($existing_keys[$k]);
+				}
 			}
 		}
 
@@ -512,8 +504,8 @@ class shelluser_base_plugin {
 		$this->app->log("ssh-rsa key updated in ".$sshkeys, LOGLEVEL_DEBUG);
 
 		// set proper file permissions
-		exec("chown -R ".escapeshellcmd($this->data['new']['puser']).":".escapeshellcmd($this->data['new']['pgroup'])." ".$sshdir);
-		exec("chmod 600 '$sshkeys'");
+		$app->system->exec_safe("chown -R ?:? ?", $this->data['new']['puser'], $this->data['new']['pgroup'], $sshdir);
+		$app->system->exec_safe("chmod 600 ?", $sshkeys);
 
 	}
 
