@@ -121,20 +121,19 @@ class shelluser_jailkit_plugin {
 						//* call the ssh-rsa update function
 						$this->_setup_ssh_rsa();
 
-						//$command .= 'usermod -s /usr/sbin/jk_chrootsh -U '.escapeshellcmd($data['new']['username']);
-						//exec($command);
 						$app->system->usermod($data['new']['username'], 0, 0, '', '/usr/sbin/jk_chrootsh', '', '');
 
 						//* Unlock user
-						$command = 'usermod -U '.escapeshellcmd($data['new']['username']).' 2>/dev/null';
-						exec($command);
+						$command = 'usermod -U ? 2>/dev/null';
+						$app->system->exec_safe($command, $data['new']['username']);
 
 						$this->_update_website_security_level();
 						$app->system->web_folder_protection($web['document_root'], true);
+						$app->log("Jailkit Plugin -> insert username:".$data['new']['username'], LOGLEVEL_DEBUG);
+					} else {
+						$app->log("Jailkit Plugin -> insert username:".$data['new']['username']. "skipped, Jailkit not selected", LOGLEVEL_DEBUG);
 					}
 
-					$app->log("Jailkit Plugin -> insert username:".$data['new']['username'], LOGLEVEL_DEBUG);
-
 				} else {
 					$app->log("Jailkit Plugin -> insert username:".$data['new']['username']." skipped, the user does not exist.", LOGLEVEL_WARN);
 				}
@@ -241,15 +240,12 @@ class shelluser_jailkit_plugin {
 
 			$jailkit_chroot_userhome = $this->_get_home_dir($data['old']['username']);
 
-			//commented out proved to be dangerous on config errors
-			//exec('rm -rf '.$data['old']['dir'].$jailkit_chroot_userhome);
-
 			$app->system->web_folder_protection($web['document_root'], false);
 			
 			$userid = intval($app->system->getuid($data['old']['username']));
-			$command = 'killall -u '.escapeshellcmd($data['old']['username']).' ; ';
-			$command .= 'userdel -f '.escapeshellcmd($data['old']['username']).' &> /dev/null';
-			exec($command);
+			$command = 'killall -u ? ; ';
+			$command .= 'userdel -f ? &> /dev/null';
+			$app->system->exec_safe($command, $data['old']['username'], $data['old']['username']);
 			
 			// Remove the jailed user from passwd and shadow file inside the jail
 			$app->system->removeLine($data['old']['dir'].'/etc/passwd', $data['old']['username']);
@@ -277,12 +273,8 @@ class shelluser_jailkit_plugin {
 		//check if the chroot environment is created yet if not create it with a list of program sections from the config
 		if (!is_dir($this->data['new']['dir'].'/etc/jailkit'))
 		{
-			$command = '/usr/local/ispconfig/server/scripts/create_jailkit_chroot.sh';
-			$command .= ' '.escapeshellcmd($this->data['new']['dir']);
-			$command .= ' \''.$this->jailkit_config['jailkit_chroot_app_sections'].'\'';
-			exec($command.' 2>/dev/null');
-
-			$this->app->log("Added jailkit chroot with command: ".$command, LOGLEVEL_DEBUG);
+			$app->system->create_jailkit_chroot($this->data['new']['dir'], $this->jailkit_config['jailkit_chroot_app_sections']);
+			$this->app->log("Added jailkit chroot", LOGLEVEL_DEBUG);
 
 			$this->_add_jailkit_programs();
 
@@ -299,7 +291,7 @@ class shelluser_jailkit_plugin {
 			$tpl->setVar('domain', $web['domain']);
 			$tpl->setVar('home_dir', $this->_get_home_dir(""));
 
-			$bashrc = escapeshellcmd($this->data['new']['dir']).'/etc/bash.bashrc';
+			$bashrc = $this->data['new']['dir'].'/etc/bash.bashrc';
 			if(@is_file($bashrc) || @is_link($bashrc)) unlink($bashrc);
 
 			file_put_contents($bashrc, $tpl->grab());
@@ -312,7 +304,7 @@ class shelluser_jailkit_plugin {
 
 			$tpl->setVar('domain', $web['domain']);
 
-			$motd = escapeshellcmd($this->data['new']['dir']).'/var/run/motd';
+			$motd = $this->data['new']['dir'].'/var/run/motd';
 			if(@is_file($motd) || @is_link($motd)) unlink($motd);
 
 			$app->system->file_put_contents($motd, $tpl->grab());
@@ -322,18 +314,15 @@ class shelluser_jailkit_plugin {
 
 	function _add_jailkit_programs()
 	{
+		global $app;
 		$jailkit_chroot_app_programs = preg_split("/[\s,]+/", $this->jailkit_config['jailkit_chroot_app_programs']);
 		if(is_array($jailkit_chroot_app_programs) && !empty($jailkit_chroot_app_programs)){
 			foreach($jailkit_chroot_app_programs as $jailkit_chroot_app_program){
 				$jailkit_chroot_app_program = trim($jailkit_chroot_app_program);
 				if(is_file($jailkit_chroot_app_program) || is_dir($jailkit_chroot_app_program)){			
 					//copy over further programs and its libraries
-					$command = '/usr/local/ispconfig/server/scripts/create_jailkit_programs.sh';
-					$command .= ' '.escapeshellcmd($this->data['new']['dir']);
-					$command .= ' '.$jailkit_chroot_app_program;
-					exec($command.' 2>/dev/null');
-
-					$this->app->log("Added programs to jailkit chroot with command: ".$command, LOGLEVEL_DEBUG);
+					$app->system->create_jailkit_programs($this->data['new']['dir'], $jailkit_chroot_app_program);
+					$this->app->log("Added programs to jailkit chroot", LOGLEVEL_DEBUG);
 				}
 			}
 		}
@@ -341,7 +330,7 @@ class shelluser_jailkit_plugin {
 
 	function _get_home_dir($username)
 	{
-		return str_replace("[username]", escapeshellcmd($username), $this->jailkit_config['jailkit_chroot_home']);
+		return str_replace("[username]", $username, $this->jailkit_config['jailkit_chroot_home']);
 	}
 
 	function _add_jailkit_user()
@@ -350,6 +339,11 @@ class shelluser_jailkit_plugin {
 
 		//add the user to the chroot
 		$jailkit_chroot_userhome = $this->_get_home_dir($this->data['new']['username']);
+		if(isset($this->data['old']['username'])) {
+			$jailkit_chroot_userhome_old = $this->_get_home_dir($this->data['old']['username']);
+		} else {
+			$jailkit_chroot_userhome_old = '';
+		}
 		$jailkit_chroot_puserhome = $this->_get_home_dir($this->data['new']['puser']);
 
 		if(!is_dir($this->data['new']['dir'].'/etc')) mkdir($this->data['new']['dir'].'/etc', 0755);
@@ -359,54 +353,29 @@ class shelluser_jailkit_plugin {
 		// ALWAYS create the user. Even if the user was created before
 		// if we check if the user exists, then a update (no shell -> jailkit) will not work
 		// and the user has FULL ACCESS to the root of the server!
-		$command = '/usr/local/ispconfig/server/scripts/create_jailkit_user.sh';
-		$command .= ' '.escapeshellcmd($this->data['new']['username']);
-		$command .= ' '.escapeshellcmd($this->data['new']['dir']);
-		$command .= ' '.$jailkit_chroot_userhome;
-		$command .= ' '.escapeshellcmd($this->data['new']['shell']);
-		$command .= ' '.$this->data['new']['puser'];
-		$command .= ' '.$jailkit_chroot_puserhome;
-		exec($command.' 2>/dev/null');
-
-		//* Change the homedir of the shell user and parent user
-		//* We have to do this manually as the usermod command fails
-		//* when the user is logged in or a command is running under that user
-		/*
-			$passwd_file_array = file('/etc/passwd');
-			$passwd_out = '';
-			if(is_array($passwd_file_array)) {
-				foreach($passwd_file_array as $line) {
-					$line = trim($line);
-					$parts = explode(':',$line);
-					if($parts[0] == $this->data['new']['username']) {
-						$parts[5] = escapeshellcmd($this->data['new']['dir'].'/.'.$jailkit_chroot_userhome);
-						$parts[6] = escapeshellcmd('/usr/sbin/jk_chrootsh');
-						$new_line = implode(':',$parts);
-						copy('/etc/passwd','/etc/passwd~');
-						chmod('/etc/passwd~',0600);
-						$app->uses('system');
-						$app->system->replaceLine('/etc/passwd',$line,$new_line,1,0);
-					}
-				}
-			}*/
+		$app->system->create_jailkit_user($this->data['new']['username'], $this->data['new']['dir'], $jailkit_chroot_userhome, $this->data['new']['shell'], $this->data['new']['puser'], $jailkit_chroot_puserhome);
 
 		$shell = '/usr/sbin/jk_chrootsh';
 		if($this->data['new']['active'] != 'y') $shell = '/bin/false';
 		
 		$app->system->usermod($this->data['new']['username'], 0, 0, $this->data['new']['dir'].'/.'.$jailkit_chroot_userhome, $shell);
-		$app->system->usermod($this->data['new']['puser'], 0, 0, $this->data['new']['dir'].'/.'.$jailkit_chroot_userhome, '/usr/sbin/jk_chrootsh');
+		$app->system->usermod($this->data['new']['puser'], 0, 0, $this->data['new']['dir'].'/.'.$jailkit_chroot_puserhome, '/usr/sbin/jk_chrootsh');
 
-		$this->app->log("Added jailkit user to chroot with command: ".$command, LOGLEVEL_DEBUG);
-
-		if(!is_dir($this->data['new']['dir'].$jailkit_chroot_userhome)) mkdir(escapeshellcmd($this->data['new']['dir'].$jailkit_chroot_userhome), 0755, true);
-		$app->system->chown(escapeshellcmd($this->data['new']['dir'].$jailkit_chroot_userhome), $this->data['new']['username']);
-		$app->system->chgrp(escapeshellcmd($this->data['new']['dir'].$jailkit_chroot_userhome), $this->data['new']['pgroup']);
+		if(!is_dir($this->data['new']['dir'].$jailkit_chroot_userhome)) {
+			if(is_dir($this->data['old']['dir'].$jailkit_chroot_userhome_old)) {
+				$app->system->rename($this->data['old']['dir'].$jailkit_chroot_userhome_old,$this->data['new']['dir'].$jailkit_chroot_userhome);
+			} else {
+				mkdir($this->data['new']['dir'].$jailkit_chroot_userhome, 0750, true);
+			}
+		}
+		$app->system->chown($this->data['new']['dir'].$jailkit_chroot_userhome, $this->data['new']['username']);
+		$app->system->chgrp($this->data['new']['dir'].$jailkit_chroot_userhome, $this->data['new']['pgroup']);
 
 		$this->app->log("Added created jailkit user home in : ".$this->data['new']['dir'].$jailkit_chroot_userhome, LOGLEVEL_DEBUG);
 
-		if(!is_dir($this->data['new']['dir'].$jailkit_chroot_puserhome)) mkdir(escapeshellcmd($this->data['new']['dir'].$jailkit_chroot_puserhome), 0755, true);
-		$app->system->chown(escapeshellcmd($this->data['new']['dir'].$jailkit_chroot_puserhome), $this->data['new']['puser']);
-		$app->system->chgrp(escapeshellcmd($this->data['new']['dir'].$jailkit_chroot_puserhome), $this->data['new']['pgroup']);
+		if(!is_dir($this->data['new']['dir'].$jailkit_chroot_puserhome)) mkdir($this->data['new']['dir'].$jailkit_chroot_puserhome, 0750, true);
+		$app->system->chown($this->data['new']['dir'].$jailkit_chroot_puserhome, $this->data['new']['puser']);
+		$app->system->chgrp($this->data['new']['dir'].$jailkit_chroot_puserhome, $this->data['new']['pgroup']);
 
 		$this->app->log("Added jailkit parent user home in : ".$this->data['new']['dir'].$jailkit_chroot_puserhome, LOGLEVEL_DEBUG);
 
@@ -435,13 +404,6 @@ class shelluser_jailkit_plugin {
 
 	}
 
-	//* Wrapper for exec function for easier debugging
-	private function _exec($command) {
-		global $app;
-		$app->log('exec: '.$command, LOGLEVEL_DEBUG);
-		exec($command);
-	}
-
 	private function _setup_ssh_rsa() {
 		global $app;
 		$this->app->log("ssh-rsa setup shelluser_jailkit", LOGLEVEL_DEBUG);
@@ -457,7 +419,7 @@ class shelluser_jailkit_plugin {
 
 		// ssh-rsa authentication variables
 		$sshrsa = $this->data['new']['ssh_rsa'];
-		$usrdir = escapeshellcmd($this->data['new']['dir']).'/'.$this->_get_home_dir($this->data['new']['username']);
+		$usrdir = $this->data['new']['dir'].'/'.$this->_get_home_dir($this->data['new']['username']);
 		$sshdir = $usrdir.'/.ssh';
 		$sshkeys= $usrdir.'/.ssh/authorized_keys';
 
@@ -477,10 +439,11 @@ class shelluser_jailkit_plugin {
 		if (!file_exists($sshkeys)){
 			// add root's key
 			$app->file->mkdirs($sshdir, '0755');
-			if(is_file('/root/.ssh/authorized_keys')) $app->system->file_put_contents($sshkeys, $app->system->file_get_contents('/root/.ssh/authorized_keys'));
+			$authorized_keys_template = $this->jailkit_config['jailkit_chroot_authorized_keys_template'];
+			if(is_file($authorized_keys_template)) $app->system->file_put_contents($sshkeys, $app->system->file_get_contents($authorized_keys_template));
 
 			// Remove duplicate keys
-			$existing_keys = @file($sshkeys);
+			$existing_keys = @file($sshkeys, FILE_IGNORE_NEW_LINES);
 			$new_keys = explode("\n", $userkey);
 			$final_keys_arr = @array_merge($existing_keys, $new_keys);
 			$new_final_keys_arr = array();
@@ -497,7 +460,7 @@ class shelluser_jailkit_plugin {
 			$this->app->log("ssh-rsa authorisation keyfile created in ".$sshkeys, LOGLEVEL_DEBUG);
 		}
 		//* Get the keys
-		$existing_keys = file($sshkeys);
+		$existing_keys = file($sshkeys, FILE_IGNORE_NEW_LINES);
 		$new_keys = explode("\n", $sshrsa);
 		$old_keys = explode("\n", $this->data['old']['ssh_rsa']);
 
@@ -505,7 +468,9 @@ class shelluser_jailkit_plugin {
 		if(is_array($old_keys)) {
 			foreach($old_keys as $key => $val) {
 				$k = array_search(trim($val), $existing_keys);
-				unset($existing_keys[$k]);
+				if ($k !== false) {
+					unset($existing_keys[$k]);
+				}
 			}
 		}
 
@@ -530,9 +495,9 @@ class shelluser_jailkit_plugin {
 		$this->app->log("ssh-rsa key updated in ".$sshkeys, LOGLEVEL_DEBUG);
 
 		// set proper file permissions
-		exec("chown -R ".escapeshellcmd($this->data['new']['puser']).":".escapeshellcmd($this->data['new']['pgroup'])." ".$sshdir);
-		exec("chmod 700 ".$sshdir);
-		exec("chmod 600 '$sshkeys'");
+		$app->system->exec_safe("chown -R ?:? ?", $this->data['new']['puser'], $this->data['new']['pgroup'], $sshdir);
+		$app->system->exec_safe("chmod 700 ?", $sshdir);
+		$app->system->exec_safe("chmod 600 ?", $sshkeys);
 
 	}
 	
@@ -554,7 +519,7 @@ class shelluser_jailkit_plugin {
 						if(is_file($homedir . $delfile) && fileowner($homedir . $delfile) == $userid) unlink($homedir . $delfile);
 					}
 					foreach($dirs as $deldir) {
-						if(is_dir($homedir . $deldir) && fileowner($homedir . $deldir) == $userid) exec('rm -rf ' . escapeshellarg($homedir . $deldir));
+						if(is_dir($homedir . $deldir) && fileowner($homedir . $deldir) == $userid) $app->system->exec_safe('rm -rf ?', $homedir . $deldir);
 					}
 					$empty = true;
 					$dirres = opendir($homedir);
